# coding: utf-8

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.v1_api import V1Api  # noqa: E501


class TestV1Api(unittest.TestCase):
    """V1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = V1Api()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_announcement_by_diff(self) -> None:
        """Test case for get_announcement_by_diff

        取得期間を指定して情報を取得  # noqa: E501
        """
        pass

    def test_get_announcement_by_number(self) -> None:
        """Test case for get_announcement_by_number

        登録番号を指定して情報を取得  # noqa: E501
        """
        pass

    def test_get_announcement_by_valid(self) -> None:
        """Test case for get_announcement_by_valid

        登録番号と日付を指定して情報を取得  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
