# coding: utf-8

# flake8: noqa

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.2"

# import apis into sdk package
from kendama.api.v1_api import V1Api

# import ApiClient
from kendama.api_response import ApiResponse
from kendama.api_client import ApiClient
from kendama.configuration import Configuration
from kendama.exceptions import OpenApiException
from kendama.exceptions import ApiTypeError
from kendama.exceptions import ApiValueError
from kendama.exceptions import ApiKeyError
from kendama.exceptions import ApiAttributeError
from kendama.exceptions import ApiException

# import models into sdk package
from kendama.models.announcement import Announcement
from kendama.models.response_body import ResponseBody
